#
# spec file for package Supybot
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           Supybot
Summary:        IRC Bot
License:        BSD-3-Clause and GPL-2.0+ and Python-2.0
Group:          Productivity/Networking/IRC
Version:        0.83.4.1
Release:        lp151.2.1
Url:            http://supybot.com/
PreReq:         %fillup_prereq %insserv_prereq
Recommends:     python-twisted python-sqlite2
BuildRequires:  fdupes
BuildRequires:  python-devel
Source:         %{name}-%{version}.tar.bz2
%define plugins_version 20060723
Source1:        %{name}-plugins-%{plugins_version}.tar.bz2
Source2:        %{name}.sysconfig
Source3:        %{name}.init
Source10:       Supybot-rpmlintrc
Patch1:         Supybot-0.83.4.1-popen_deprecated.patch
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{py_requires}
%{!?python_sitelib:  %global python_sitelib  %(%__python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%__python -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

%description
Supybot is a robust, user and programmer friendly IRC bot written in
Python. It aims to be an adequate replacement for most existing IRC
bots. It includes a very flexible and powerful ACL system for
controlling access to commands, as well as more than 50 builtin plugins
providing around 400 actual commands.


%prep
%setup -q -b 1
%patch1 -p0
cp -a ../%{name}-plugins-%{plugins_version}/* plugins/

%build
export CFLAGS=$RPM_OPT_FLAGS
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot} --record-rpm=INSTALLED_FILES
install -d %{buildroot}/%{_mandir}/man1
install -m 644 docs/man/*.1 %{buildroot}/%{_mandir}/man1
# fix non executable scripts
chmod +x %{buildroot}/%{python_sitelib}/supybot/plugins/RSS/local/feedparser.py
chmod +x %{buildroot}/%{python_sitelib}/supybot/plugins/Supybot/plugin.py
chmod +x %{buildroot}/%{python_sitelib}/supybot/plugins/ExternalNotice/supybot-external-notice.py
# install init and sysconfig script
install -Dm644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.supybot
install -Dm755 %{SOURCE3} %{buildroot}/%{_sysconfdir}/init.d/supybot
mkdir -p %{buildroot}/%{_sbindir}
ln -s %{_sysconfdir}/init.d/supybot %{buildroot}/%{_sbindir}/rcsupybot
%fdupes %{buildroot}

%post
%fillup_and_insserv supybot

%preun
%stop_on_removal supybot

%postun
%restart_on_update supybot
%insserv_cleanup

%files -f INSTALLED_FILES
%defattr(-, root, root)
%doc ACKS ChangeLog LICENSE README RELNOTES docs/GETTING_STARTED
%doc %{_mandir}/man1/*.gz
%{_fillupdir}/sysconfig.supybot
%{_sysconfdir}/init.d/supybot
%{_sbindir}/rcsupybot

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Mar 18 2013 coolo@suse.com
- add changes entry for the license change
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Jun 16 2010 mrueckert@suse.de
- make it build on sle11:
  - define the new python path variables when they are not defined
  - only build noarch on distros that support it
* Wed Jan 20 2010 lars@linux-schulserver.de
- added Supybot-0.83.4.1-popen_deprecated.patch to avoid
  deprecation warnings (Thanks to Martin Lillepuu)
- small specfile cleanup
- build as noarch
* Sun Dec 20 2009 coolo@novell.com
- remove support for outdated distros
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Tue May 26 2009 lrupp@suse.de
- update to 0.83.4.1:
  + Simple bug-fix release for a couple changes that were introduced
    last minute before the previous release.
- add Recommends: python-twisted python-sqlite2
* Tue May 19 2009 lrupp@suse.de
- update to 0.83.4:
  + This release contains fixes for Python2.6 compability as well
    as a re-written Google plugin which uses the AJAX API.
    The re-written plugin gained a translate command and no longer
    needs an API key.
  + ChannelLogger has a new config variable, supybot.plugins.ChannelLogger.enable,
    which can be used on a per-channel basis to determine whether
    that channel is logged.
  + The RSS announce command has been restructured into the commands
    "announce list", "announce remove", and "announce add" in order
    to simplify the command's use.
  + The supybot.directories.plugins config variable now determines
    its global directory dynamically instead of adding the directory
    to the value.
    This means values like '/usr/lib/python2.5/site-packages/supybot/plugins'
    can be removed from the variable.  This should help ease
    transitioning a Supybot config from one Python release to another.
  + Incompatibilities:
  ++ supybot.plugins.Google.safeSearch has been renamed to
    supybot.plugins.Google.searchFilter
  ++ supybot.plugins.Channel.banmask has been removed in favor of
    a new supybot.protocols.irc.banmask config variable. This
    general config variable is used by the various commands which
    would need to know what style of banmask to use.
- removed Supybot-0.83.3.diff
* Mon Nov  3 2008 schwab@suse.de
- Remove use of deprecated modules.
* Thu Jul 24 2008 lrupp@suse.de
- fix typo in init script
* Fri May  9 2008 lrupp@suse.de
- added Supybot.init and Supybot.sysconfig script to
  start and stop Supybot automatically during runlevel changes
* Wed Oct 24 2007 schwab@suse.de
- Update to Supybot 0.83.3.
  * Added the BadWords plugin from supybot-plugins and updated the
  plugin to allow kicking of people who use defined BadWords.
  * Added support for different log levels on stdout vs the log file.
  * Fixed a bug where the bot always reacted to invalid command floods
  even if supybot.abuse.flood.command.invalid indicated not to.
  (Closes: #1716878)
  * Fixed a bug where the RSS plugin would lower-case URLs, thus making
  them impossible to retrieve.  (Closes: #1666786)
  * Fixed ircmsgs.prettyPrint to handle unrecognized commands.
  (Closes: #1630963)
  * Fixed a bug in the Services plugin where the bot would continuously
  send Ghost commands.
  * Fixed Google.calc to handle a change in Google's HTML.
  * Fixed a bug where Plugin.list was listing functions which weren't
  valid commands.
  * Fixed RSS's handling of encodings to eliminate some ascii conversion
  errors.
  * Updated the rssparser using plugins with the renamed and newer
  feedparser 4.1 in order to properly handle Bugzilla RSS feeds.
  * Updated PLUGIN_TUTORIAL to specify that the user needs to import
  Python's random module.
  * Updated the Web plugin so it uses HTMLParser over sgmllib's parser
  since sgmllib's enters an infinite loop on invalid input.
  * Updated getHelp() so callers can pass in the help string.  This is
  used in the Factoids plugin to dynamically generate a help string
  based on a config value.
  * Updated questions.py so bolding is handled better.  User input,
  default values, and defined choices are no longer bolded.
  * Updated String.len to use wrap().  This greatly simplifies the
  command and introduces better argument handling.
  * Updated a few uses of sre to use re if the bot is running under
  Python 2.5.
  * Fixed test cases for mircColor and sorted (thanks dcraven).
  * Updated assertAction's error message to give useful information
  about what went wrong.
* Mon Jul 24 2006 schwab@suse.de
- Update to Supybot 0.83.2 (bug fixes).
* Fri Jul  7 2006 schwab@suse.de
- Allow floating point values in Weather plugin.
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Mon Feb  6 2006 schwab@suse.de
- Fix parsing in Weather plugin.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Dec 10 2005 schwab@suse.de
- Update to Supybot 0.83.1.
* Fri Aug 12 2005 schwab@suse.de
- Remove noarch.
* Tue Jun 21 2005 schwab@suse.de
- More fixes for weather parsing.
* Fri May 27 2005 schwab@suse.de
- Fix parsing in Weather plugin.
* Tue May 24 2005 schwab@suse.de
- Fix "config help" message.
* Mon May 23 2005 schwab@suse.de
- Initial version 0.80.1
